Flex
====

The flexible file fomat.

Structure:
 - main folder tar (.gz)
 - contains one (1) header.json file, with Metadata (primary header)
 - contains any number of folders with more data
 - e.g. numpy data, pandas table
 - each folder must contain a header in the form of a header.json file
 - each type of container gets a file in "extension", container type is set in that extensions header.json
 
